@@ -13,8 +13,8 @@ import difflib
 import datetime
 from git import Repo
 import os
+import pathlib
 import re
-from pathlib import Path
 import sys
 from argparse import ArgumentParser
 from argparse import RawDescriptionHelpFormatter
@@ -350,13 +350,13 @@ class WikiPush(object):
         self.ensureDirectoryExists(directory)
         
     def ensureDirectoryExists(self,directory):
-        Path(directory).mkdir(parents=True, exist_ok=True)
+        pathlib.Path(directory).mkdir(parents=True, exist_ok=True)
         
     def getHomePath(self,localPath):
         '''
         get the given home path
         '''
-        homePath=str(Path.home() / localPath)
+        homePath=f"{pathlib.Path.home()}/{localPath}"
         self.ensureDirectoryExists(homePath)
         return homePath
                     
@@ -411,12 +411,18 @@ class WikiPush(object):
         Args:
             warnings(list): a list of API warnings
             ignoreExists(bool): ignore messages that warn about existing content
+
+        Returns:
+            bool: True if the exception was handled as ok False if it was logged as an error
         '''
         msg=""
         if warnings:
-            for warning in warnings:
-                msg+="%s\n" % str(warning)
-        self.handleWarning(msg,ignoreExists=ignoreExists)
+            if isinstance(warnings, str):
+                msg = warnings
+            else:
+                for warning in warnings:
+                    msg+="%s\n" % str(warning)
+        return self.handleWarning(msg,ignoreExists=ignoreExists)
         
     def handleWarning(self,msg,marker="⚠️",ignoreExists=False):
         '''
@@ -433,9 +439,11 @@ class WikiPush(object):
         #print ("handling warning %s with ignoreExists=%r" % (msg,ignoreExists))
         if ignoreExists and "exists" in msg:
             # shorten exact duplicate message
-            if "exact duplicate in msg":
+            if "exact duplicate" in msg:
                 msg="exact duplicate"
             marker="👀"
+        if not ignoreExists and "exists" in msg:
+            msg="file exists (to overwrite existing files enable the ignore parameter)"
         self.log("%s:%s" % (marker,msg))
         return marker=="👀"
                 
@@ -523,9 +531,9 @@ class WikiPush(object):
             except Exception as ex:
                 self.log("❌:%s" % str(ex) )
 
-__version__ = "0.5.1"
+__version__ = "0.5.4"
 __date__ = '2020-10-31'
-__updated__ = '2021-12-13'
+__updated__ = '2022-02-06'
 DEBUG=False
 
 def mainNuke(argv=None):
